# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   momth8_day7_bpm_final
# FileName:      read_excel.py
# Author:       李浩东
# Datetime:     2023/8/7 18:53
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl

from BPM_common.read_ini import READ_INI
from BPM_common.read_json import get_json_dict


class READ_EXCEL:
    def __init__(self):
        case_data_file_path=READ_INI().get_filepath("case_json")
        case_expect_file_path=READ_INI().get_filepath("expect_json")
        case_sql_file_path=READ_INI().get_filepath("sql_json")

        self.case_data_dict=get_json_dict(case_data_file_path)
        self.case_expect_data_dict=get_json_dict(case_expect_file_path)
        self.case_sql_dict=get_json_dict(case_sql_file_path)

        excel_path=READ_INI().get_filepath("excel_name")
        self.wb=openpyxl.load_workbook(excel_path)
        self.ws=self.wb[READ_INI().get_table_name("table")]

    def __get_cell_value(self,column:str,row:int)->str:
        value=self.ws[str(column)+str(row)].value
        if value is None:
            return None
        elif value.strip():
            return value.strip()

    def module_name(self,row):
        return self.__get_cell_value("B",row)

    def interface_name(self,row):
        return self.__get_cell_value("C",row)

    def title_name(self,row):
        return self.__get_cell_value("D",row)

    def case_level(self,row):
        return self.__get_cell_value("E",row)

    def post_method(self,row):
        return self.__get_cell_value("F",row)

    def request_url(self,row):
        host = READ_INI().get_host("BPM_host")
        return host+self.__get_cell_value("G",row)

    def case_mime(self,row):
        mime=self.__get_cell_value("H",row)
        if mime:
            return mime.lower()

    def case_data(self,row):
        case_data = self.__get_cell_value("I", row)
        if case_data:
            module=self.module_name(row)
            interface=self.interface_name(row)
            return self.case_data_dict[module][interface][case_data]

    def expect_data(self,row):
        expect_data=self.__get_cell_value("J",row)
        if expect_data:
            module = self.module_name(row)
            interface = self.interface_name(row)
            return self.case_expect_data_dict[module][interface][expect_data]

    def sql_type(self,row):
        sql_type=self.__get_cell_value("K",row)
        if sql_type:
            return sql_type.lower()

    def sql_statement(self,row):
        sql_statement=self.__get_cell_value("L",row)
        if sql_statement:
            module = self.module_name(row)
            interface = self.interface_name(row)
            return self.case_sql_dict[module][interface][sql_statement]

    def update_key(self,row):
        return self.__get_cell_value("M",row)

    def all_data(self):
        data_list=[]
        for row in range(2,self.ws.max_row+1):
            module_name=self.module_name(row)
            interface_name=self.interface_name(row)
            title_name=self.title_name(row)
            case_level=self.case_level(row)
            request_method=self.post_method(row)
            request_url=self.request_url(row)
            request_mime=self.case_mime(row)
            case_data=self.case_data(row)
            expect_data=self.expect_data(row)
            sql_type=self.sql_type(row)
            sql_statement=self.sql_statement(row)
            update_key=self.update_key(row)
            data_list.append([module_name,interface_name,title_name,case_level,request_method,request_url,request_mime,case_data,expect_data,sql_type,sql_statement,update_key])
        return data_list

if __name__ == '__main__':
    print(READ_EXCEL().all_data())


